@@ -64,7 +64,7 @@ public:
      * @param text   Text label for the node.
      * @param pixmap A pixmap to display to the left of the text.
      */
-    Node( int type, const char* text, const QPixmap& pixmap );
+    Node( int type, const QString & text, const QPixmap& pixmap );
 
     /**
      * There must be a virtual destructor in the base class so that all the
@@ -348,7 +348,7 @@ public:
      * @param pixmap A pixmap to display to the left of the text.
      * @param state  The initial selection state of the node.
      */
-    SelectableNode( int type, const char* text, const QPixmap& pixmap, int state );
+    SelectableNode( int type, const QString & text, const QPixmap& pixmap, int state );
 
     /**
      * Determine whether the node is an instance of the given node type.
@@ -393,7 +393,7 @@ public:
      * @param pixmap A pixmap to display to the left of the text.
      * @param state  The initial selection state of the node.
      */
-    RangeableNode( int type, const char* text, const QPixmap& pixmap, int state );
+    RangeableNode( int type, const QString & text, const QPixmap& pixmap, int state );
 
     /**
      * Get a list of all the selected ranges for the subtree rooted at this
@@ -506,7 +506,7 @@ public:
      *
      * @return The full path name of the directory.
      */
-    const char* getFullPath();
+    QString getFullPath();
 
     /**
      * Get a list of all the selected ranges for the subtree rooted at this
@@ -586,7 +586,7 @@ public:
      *
      * @return The full path name of the file.
      */
-    const char* getFullPath();
+    QString getFullPath();
 
     /**
      * Get a list of all the selected ranges for the subtree rooted at this
@@ -636,7 +636,7 @@ public:
      * @param pixmap A pixmap to display to the left of the text.
      * @param state  The initial selection state of the node.
      */
-    ArchiveableNode( int type, const char* text, const QPixmap& pixmap, int state );
+    ArchiveableNode( int type, const QString & text, const QPixmap& pixmap, int state );
 
     /**
      * Compute the full path name of this node.  Nodes representing
@@ -644,7 +644,7 @@ public:
      *
      * @return The full path of the file that this node represents.
      */
-    virtual const char* getFullPath() = 0;
+    virtual QString getFullPath() = 0;
 
     /**
      * Determine whether the node is an instance of the given node type.
@@ -671,7 +671,7 @@ public:
      *
      * @return The full path of the file that this node represents.
      */
-    virtual const char* getFullPath();
+    virtual QString getFullPath();
 
     /**
      * Determine whether the node is an instance of the given node type.
@@ -723,7 +723,7 @@ public:
      *              traversing the tree to the root node.
      * @param state The initial selection state of the node.
      */
-    DirectoryNode( const char* text, int state );
+    DirectoryNode( const QString & text, int state );
 
     /**
      * Compute the full path name of this node.  Nodes representing
@@ -731,7 +731,7 @@ public:
      *
      * @return The full path of the file that this node represents.
      */
-    virtual const char* getFullPath();
+    virtual QString getFullPath();
 
     /**
      * Determine whether the node is an instance of the given node type.
@@ -782,7 +782,7 @@ public:
      *              traversing the tree to the root node.
      * @param state The initial selection state of the node.
      */
-    FileNode( const char* text, int state );
+    FileNode( const QString & text, int state );
 
     /**
      * Compute the full path name of this node.  Nodes representing
@@ -790,7 +790,7 @@ public:
      *
      * @return The full path of the file that this node represents.
      */
-    virtual const char* getFullPath();
+    virtual QString getFullPath();
 
     /**
      * Determine whether the node is an instance of the given node type.
