@@ -190,7 +190,7 @@ public slots:
      * @param data   An array of data bytes.
      * @param length The length of the data array.
      */
-    void slotData( const char* data, int length );
+    void slotData( const QString & data, int length );
 signals:
     /**
      * This signal is emitted whenever a file entry is parsed from the archive.
@@ -200,7 +200,7 @@ signals:
      * @param mtime  The last modification time for the file.
      * @param record The tar record that this file begins on.
      */
-    void sigEntry( const char* name, int size, int mtime, int record );
+    void sigEntry( const QString & name, int size, int mtime, int record );
 };
 
 #endif
