@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////
-// $Id: managementWidget.h,v 1.13 2000/05/02 15:01:39 toivo Exp $	
+// $Id: managementWidget.h,v 1.15 2000/08/25 13:29:26 toivo Exp $	
 // File  : managementWidget.h
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -45,15 +45,15 @@ class managementWidget : public QFrame
 
   ///////////// METHODS ------------------------------------------------------
 public:
-  managementWidget(QWidget *parent=0, const char *name=0);
+  managementWidget(QWidget *parent=0);
   // Constructor
 
   ~managementWidget();
   // Destructor
 
-  KPLVItem *search(const char *str, const char* head,
+  KPLVItem *search(QString str, QString head,
 			KPLVItem  *start = 0);
-  KPLVItem *search(const char *str, bool subStr, bool wrap, bool start);
+  KPLVItem *search(QString str, bool subStr, bool wrap, bool start);
   // search for a package in tree
 
   KPLVItem *changePack(KPLVItem *searchResult, bool push = true);
@@ -125,6 +125,7 @@ private:
   // data contained about the packages has been changed (e.g. a verification
   // failed / succeeded).
 
+  void stackRemove(KPLVItem *pack);
   void next();
   void previous();
 
@@ -179,7 +180,7 @@ private:
 
   KPLVItem *searchCitem;
   bool searchSkip, searchSubstr;
-  const char *searchStr;
+  QString searchStr;
   KPLVItem  *searchResult;
   // globals used by searchChild for start from current position,
   // skip to current item before search flag, substring search flag, 
