@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: procbuf.h,v 1.2 2000/06/07 15:39:03 toivo Exp $ 
+//      $Id: procbuf.h,v 1.3 2000/08/05 19:45:51 bieker Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -14,7 +14,7 @@
 class Modal : public QDialog {
   Q_OBJECT
 public:
-  Modal(QString msg, QWidget *parent, QString name );
+  Modal(QString msg, QWidget *parent, const char * name );
   void terminate();
 };
 
@@ -30,7 +30,7 @@ public:
    KProcess *proc; 
    Modal *m;
    QString command;
-   int start(QString msg, bool errorDlg = TRUE);
+   int start(const QString & msg, bool errorDlg = TRUE);
 
 public slots:
   void slotReadInfo(KProcess *, char *, int);
