@@ -13,17 +13,15 @@
  *   the Free Software Foundation; version 2.                              *
  *                                                                         *
  ***************************************************************************/
-#pragma implementation
-
 // KSysV Config Object
 
 #include <kapp.h>
 #include <kglobal.h>
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 #include <kconfig.h>
-#include "ksv_conf.h"
 
-#include "Constants.h"
+#include "ksv_core.h"
+#include "ksv_conf.h"
 
 KSVConfig::KSVConfig ()
   : mConfig (KGlobal::config()),
@@ -41,22 +39,23 @@ void KSVConfig::setPanningFactor (int val)
 
 void KSVConfig::readSettings()
 {
-  mConfig->setGroup("Path Settings");
-  
+  mConfig->setGroup("Path Settings"); 
   mScriptPath = mConfig->readEntry("ScriptPath", "/etc/rc.d/init.d");
   mRunlevelPath = mConfig->readEntry("RunlevelPath", "/etc/rc.d");
 
   mConfig->setGroup("Other Settings");
-
   mShowLog = mConfig->readBoolEntry("ShowLog", true);
   mShowStatus = mConfig->readBoolEntry("StatusBar", true);
   mShowTools = mConfig->readBoolEntry("ToolBar", true);
   mConfigured = mConfig->readBoolEntry("Configured", false);
   mPanningFactor = mConfig->readNumEntry("PanningFactor", 80);
   mShowDescription = mConfig->readBoolEntry("ShowDescription", true);
+
   mConfig->setGroup("Colors");
-  mNewNormalColor = mConfig->readColorEntry("New", &Qt::blue);
-  mChangedNormalColor = mConfig->readColorEntry("Changed", &Qt::red);
+  mNewNormalColor = mConfig->readColorEntry ("New Text", &Qt::blue);
+  mNewSelectedColor = mConfig->readColorEntry ("New Selected Text", &Qt::blue);
+  mChangedNormalColor = mConfig->readColorEntry ("Changed Text", &Qt::red);
+  mChangedSelectedColor = mConfig->readColorEntry ("Changed Selected Text", &Qt::red); 
 
   readRunlevels();
 }
@@ -99,7 +98,7 @@ void KSVConfig::writeSettings() {
   mConfig->writeEntry("Changed", mChangedNormalColor);
 
   // save screen geometry
-  KTMainWindow* mw = static_cast<KTMainWindow*>(kapp->mainWidget());
+  KMainWindow* mw = static_cast<KMainWindow*>(kapp->mainWidget());
 
   mConfig->setGroup("Geometry");
   mConfig->writeEntry("X-Position", mw->x());
@@ -131,7 +130,7 @@ void KSVConfig::readRunlevels ()
 	mShowRunlevel[*it] = true;
 
   if (mShowRunlevel.isEmpty())
-	for (int i = 0; i < RUNLEVEL_NR; ++i)
+	for (int i = 0; i < ksv::runlevelNumber; ++i)
 	  mShowRunlevel[i] = true;
 }
 
@@ -185,3 +184,22 @@ KSVConfig* KSVConfig::self()
   return &conf;
 }
 
+void KSVConfig::setNewNormalColor (const QColor& col)
+{
+  mNewNormalColor = col;
+}
+
+void KSVConfig::setNewSelectedColor (const QColor& col)
+{
+  mNewSelectedColor = col;
+}
+
+void KSVConfig::setChangedNormalColor (const QColor& col)
+{
+  mChangedNormalColor = col;
+}
+
+void KSVConfig::setChangedSelectedColor (const QColor& col)
+{
+  mChangedSelectedColor = col;
+}
