@@ -20,13 +20,12 @@
 #include "misc.h"
 
 #include "addUser.h"
-#include <qmessagebox.h>
 
 #ifdef _KU_QUOTA
 addUser::addUser(KUser &AUser, Quota &AQuota, QWidget *parent, const char *name, int isprep) :
   propdlg(AUser, AQuota, parent, name, isprep) {
 #else
-addUser::addUser(KUser &AUser, QWidget *parent = 0, const char *name = 0, int isprep = false) :
+addUser::addUser(KUser &AUser, QWidget *parent, const char *name, int isprep) :
   propdlg(AUser, parent, name, isprep) {
 #endif
 
@@ -110,7 +109,7 @@ bool addUser::checkHome() {
   struct stat s;
   int r;
 
-  r = stat(user.getHomeDir(), &s);
+  r = stat(QFile::encodeName(user.getHomeDir()), &s);
 
   if ((r == -1) && (errno = ENOENT))
     return true;
@@ -138,7 +137,7 @@ bool addUser::checkMailBox() {
   int r;
 
   mailboxpath = QString("%s/%s").arg(MAIL_SPOOL_DIR).arg(user.getFullName());
-  r = stat(mailboxpath, &s);
+  r = stat(QFile::encodeName(mailboxpath), &s);
   
   if ((r == -1) && (errno == ENOENT))
     return true;
